@@ -12,6 +12,10 @@ from bokeh.tile_providers import get_provider
 
 from .base import embedded_html
 
+from bokeh.colors import RGB
+import bokeh
+from bokeh.models import TickFormatter, NumeralTickFormatter
+
 blue_colormap = [RGB(255 - i, 255 - i, 255) for i in range(256)]
 
 TILE_PROVIDERS = [
@@ -188,6 +192,7 @@ def geoplot(
         LinearColorMapper,
         GeoJSONDataSource,
         WheelZoomTool,
+        BoxZoomTool,
         ColorBar,
         BasicTicker,
         LogTicker,
@@ -230,6 +235,7 @@ def geoplot(
         "active_scroll": "wheel_zoom",
         "x_axis_type": "mercator",
         "y_axis_type": "mercator",
+        "match_aspect": True,
     }
     if not figsize is None:
         width, height = figsize
@@ -423,6 +429,16 @@ def geoplot(
     # Create Figure to draw:
     old_layout = None
     if figure is None:
+        figure_options["x_axis_label"] = (
+            figure_options["x_axis_label"]
+            if figure_options["x_axis_label"] is not None
+            else "Longitute"
+        )
+        figure_options["y_axis_label"] = (
+            figure_options["y_axis_label"]
+            if figure_options["y_axis_label"] is not None
+            else "Latitude"
+        )
         p = bokeh.plotting.figure(**figure_options)
 
         # Add Tile Source as Background:
@@ -440,10 +456,13 @@ def geoplot(
             "Parameter <figure> has to be of type bokeh.plotting.figure or bokeh.layouts.column."
         )
 
-    # Get ridd of zoom on axes:
     for t in p.tools:
-        if type(t) == WheelZoomTool:
+        # Get ridd of zoom on axes:
+        if isinstance(t, WheelZoomTool):
             t.zoom_on_axis = False
+        # Make sure that box zoom matches aspect:
+        if isinstance(t, BoxZoomTool):
+            t.match_aspect = True
 
     # Hide legend if wanted:
     legend_input = legend
